@@ -25,12 +25,14 @@ class simulation:
                  BOUNDARYH = 'src/Include/Boundary.h',
                  log_name = 'tmp.log',
                  run_command = 'mpirun',
+                 run_prefix = ''
                  ):
         #Default variables
         self.proc_num = proc_num
         self.PARTIESINP = PARTIESINP
         self.log_name = log_name
         self.run_command = run_command
+        self.run_prefix=run_prefix
         self.tmp_log_file = None
         self.parties = None #process variable - to start/stop simulation
         self.status = False
@@ -41,11 +43,11 @@ class simulation:
 
     def run(self, folder='.'):
         self.log_name = self.main_dir + self.log_name
-        self.tmp_log_file = open(self.log_name,'a')
-        if self.proc_num > 1:
-            self.parties = subprocess.Popen([self.run_command,'-np', str(self.proc_num), './parties'],stdout=self.tmp_log_file,cwd=folder)
-        if self.proc_num == 1:
-            self.parties = subprocess.Popen(['./parties'],stdout=self.tmp_log_file,cwd=folder)
+        with open(self.log_name,'w') as log_file:
+            if self.proc_num > 1:
+                self.parties = subprocess.Popen([self.run_prefix,self.run_command,'-np', str(self.proc_num), './parties'],stdout=log_file,cwd=folder)
+            if self.proc_num == 1:
+                self.parties = subprocess.Popen(['./parties'],stdout=log_file,cwd=folder)
         self.status = True
 
     def stop(self):
@@ -54,6 +56,7 @@ class simulation:
 
     def check_status(self):
         if self.parties.poll() != 0: return 1
+        if self.parties.poll() == 1: return 0
         else: return 0
 
     def change_line(self, file_name, line_keyword, value):
@@ -93,17 +96,25 @@ class post_process:
         self.main_dir = os.getcwd() + '/'
     
     def get(self, name, idx, flags, **kwargs):
+        
+        def open_h5_file(filename):
+            waiting_time=0
+            while (waiting_time < 100):
+                try:
+                    f = h5py.File(filename,'r')
+                    break
+                except:
+                    time.sleep(1)
+                    waiting_time +=1
+            if waiting_time == 100:
+                print('ERROR: File was not been able to open for 10s !!!')
+                return -1
+            return f
+
         pstfx=''
         if self.postfix != '': pstfx=self.postfix + '/'
         filename= self.main_dir+pstfx+name+'_'+str(idx)+'.h5'
-        try:
-            f = h5py.File(filename,'r')
-        except:
-            try:
-                time.sleep(0.1)
-                f = h5py.File(filename,'r')
-            except:
-                print('Unable to open the file - ' + filename)
+        f=open_h5_file(filename)
 
         try:
             for i,flag in enumerate(flags):
@@ -219,7 +230,8 @@ class multiple_simulations:
                  vars = None,
                  run_command='mpirun',
                  p_fixed = None,
-                 p_mobile=None
+                 p_mobile=None,
+                 run_prefix = ''
                  ):
         
         self.n_avail_proc = n_avail_proc
@@ -227,6 +239,7 @@ class multiple_simulations:
         self.vars = vars #iteratable variables
         self.p_fixed=p_fixed
         self.p_mobile=p_mobile
+        self.run_prefix=run_prefix
         
         self.sim_list=[]
         self.run_command = run_command
@@ -271,7 +284,8 @@ class multiple_simulations:
         for idx, rows in self.vars.iterrows():
             s = simulation(proc_num=self.n_pps,
                            run_command=self.run_command,
-                           log_name=self.postfix+'/tmp.log')
+                           log_name=self.postfix+'/tmp.log',
+                           run_prefix=self.run_prefix)
             self.set_postfix(cols,rows)
             sim = {'simulation':s,
                    'postfix':self.postfix,
